@@ -6,7 +6,7 @@ from .decorators import (  # noqa
     RateLimitException,
     context_cache_detect,
 )
-from .helpers import add_prefix, at  # noqa
+from .helpers import add_prefix  # noqa
 from .validation import set_invalidate_further  # noqa
 from .wrapper import Cache  # noqa
 
@@ -26,5 +26,5 @@ invalidate_func = cache.invalidate_func
 
 mem = Cache()
 mem.setup(
-    "mem://?check_interval=1", size=1_000_000, middlewares=(add_prefix("mem:"),),
+    "mem://?check_interval=1", size=1_000_000,
 )  # 1_000_000 * 248(size of small dict) == 31 mb
