@@ -87,12 +87,16 @@ def _get_call_values(func, args, kwargs):
 
 
 class _ReFormatter(Formatter):
+    def __init__(self, reg_field=lambda f: f):
+        self._reg_field = reg_field
+        super().__init__()
+
     def get_field(self, field_name, args, kwargs):
         try:
             return super().get_field(field_name, args, kwargs)
         except (KeyError, AttributeError):
-
-            return f"(?P<{field_name.replace('.', '_')}>.*)", None
+            self._reg_field(field_name)
+            return f"(?P<{field_name.replace('.', '_')}>[^:]*)", None
 
 
 class _Blank(Formatter):
@@ -107,7 +111,7 @@ class _Blank(Formatter):
             return self.__default, None
 
 
-def template_to_pattern(template: str, _formatter=_Blank(), **values):
+def template_to_pattern(template: str, _formatter=_Blank(), **values) -> str:
     return _formatter.format(template, **values)
 
 
@@ -115,17 +119,19 @@ _REGISTER = {}
 
 
 def register_template(func, template: str):
-    pattern = template_to_pattern(template, _formatter=_ReFormatter())
-    compile_pattern = re.compile(pattern)
-    _REGISTER.setdefault((func.__module__, func.__name__), set()).add((template, compile_pattern))
+    fields = []
+    pattern = "(.*[:])?" + template_to_pattern(template, _formatter=_ReFormatter(fields.append)) + "$"
+    compile_pattern = re.compile(pattern, flags=re.MULTILINE)
+    _REGISTER.setdefault((func.__module__, func.__name__), set()).add((template, compile_pattern, tuple(fields)))
 
 
 def get_templates_for(func):
-    return (template for template, _ in _REGISTER.get((func.__module__, func.__name__), set()))
+    return (template for template, _, _ in _REGISTER.get((func.__module__, func.__name__), set()))
 
 
-def get_template_and_func_for(key: str):
+def get_template_and_func_for(key: str) -> Tuple[Optional[str], Optional[Callable]]:
     for func, templates in _REGISTER.items():
-        for template, compile_pattern in templates:
-            if compile_pattern.match(key):
+        for template, compile_pattern, _ in templates:
+            if compile_pattern.fullmatch(key):
                 return template_to_pattern(template), func
+    return None, None
